#
# spec file for package python-actdiag
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
%{?sle15_python_module_pythons}
Name:           python-actdiag
Version:        3.0.0
Release:        4.1
Summary:        Text to activity-diagram image generator
License:        Apache-2.0
URL:            http://blockdiag.com/
Source:         https://files.pythonhosted.org/packages/source/a/actdiag/actdiag-%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#blockdiag/actdiag#25
Patch0:         clean-up-assertions.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module blockdiag >= 3}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-blockdiag >= 3
BuildArch:      noarch
%python_subpackages

%description
actdiag generates activity-diagram image files from spec-text files.

%prep
%autosetup -p1 -n actdiag-%{version}
# python-blockdiag-nose-to-pytest.patch of python-blockdiag changed the function name
sed -i 's/testcase_generator/_testcase_generator/' src/actdiag/tests/test_generate_diagram.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/actdiag
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest src/actdiag/tests

%pre
%python_libalternatives_reset_alternative actdiag

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/actdiag
%{python_sitelib}/actdiag
%{python_sitelib}/actdiag-%{version}.dist-info

%changelog
* Mon Jun 16 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Mon Apr  8 2024 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons
* Thu Jan 18 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Add patch clean-up-assertions.patch:
  * Use non-deprecated assertion functions.
* Thu Aug  4 2022 Ben Greiner <code@bnavigator.de>
- Fix the requirements
- Enable tests
- Don't catchall files
* Thu Aug  4 2022 Otto Hollmann <otto.hollmann@suse.com>
- Update to 3.0.0
  * Drop python3.6 support
  * Use funcparserlib-1.0.0a0 or newer to support new python versions
  * Allow to write multiline string via triple quotes (""" ... """)
  * Fix a bug: Fix #147: file existence disclosure using svg renderer
* Wed May 27 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Feb 25 2020 Thomas Bechtold <tbechtold@suse.com>
- update to 2.0.0:
  * Drop python2 and python3.4 support
* Tue Jan  8 2019 Jonathan Brownell <jbrownell@suse.com>
- Update conditionals to use Suggests properly based on RHEL version
* Tue Jan  8 2019 Thomas Bechtold <tbechtold@suse.com>
- Use Requires instead of Suggests for RHEL/Fedora systems
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Sep  7 2017 tbechtold@suse.com
- Initial packaging (version 0.5.4)
